@@ -25,9 +25,7 @@ class PyXploraApi(PyXplora):
         timeZone: str,
         childPhoneNumber=[],
     ) -> None:
-        super().__init__(
-            countrycode, phoneNumber, password, userLang, timeZone, childPhoneNumber
-        )
+        super().__init__(countrycode, phoneNumber, password, userLang, timeZone, childPhoneNumber)
 
     async def __login(self, forceLogin=False) -> dict:
         if not self._isConnected() or self._hasTokenExpired() or forceLogin:
@@ -42,9 +40,7 @@ class PyXploraApi(PyXplora):
                 )
                 if self._gqlHandler:
                     retryCounter = 0
-                    while not self._isConnected() and (
-                        retryCounter < self.maxRetries + 2
-                    ):
+                    while not self._isConnected() and (retryCounter < self.maxRetries + 2):
                         retryCounter += 1
 
                         # Try to login
@@ -59,9 +55,7 @@ class PyXploraApi(PyXplora):
                     if self._issueToken:
                         self.dtIssueToken = int(time())
                 else:
-                    raise Exception(
-                        "Unknown error creating a new GraphQL handler instance."
-                    )
+                    raise Exception("Unknown error creating a new GraphQL handler instance.")
             except Exception:
                 # Login failed.
                 self._gqlHandler = None
@@ -116,12 +110,8 @@ class PyXploraApi(PyXplora):
                                 {
                                     "id": id,
                                     "guardianType": contact["guardianType"],
-                                    "create": datetime.fromtimestamp(
-                                        contact["create"]
-                                    ).strftime("%Y-%m-%d %H:%M:%S"),
-                                    "update": datetime.fromtimestamp(
-                                        contact["update"]
-                                    ).strftime("%Y-%m-%d %H:%M:%S"),
+                                    "create": datetime.fromtimestamp(contact["create"]).strftime("%Y-%m-%d %H:%M:%S"),
+                                    "update": datetime.fromtimestamp(contact["update"]).strftime("%Y-%m-%d %H:%M:%S"),
                                     "name": contact["name"],
                                     "phoneNumber": f"+{contact['countryPhoneNumber']}{contact['phoneNumber']}",
                                     "xcoin": xcoin,
@@ -191,9 +181,9 @@ class PyXploraApi(PyXplora):
                     if location_raw["watchLastLocate"] is not None:
                         watch_location.append(
                             {
-                                "tm": datetime.fromtimestamp(
-                                    location_raw["watchLastLocate"]["tm"]
-                                ).strftime("%Y-%m-%d %H:%M:%S"),
+                                "tm": datetime.fromtimestamp(location_raw["watchLastLocate"]["tm"]).strftime(
+                                    "%Y-%m-%d %H:%M:%S"
+                                ),
                                 "lat": location_raw["watchLastLocate"]["lat"],
                                 "lng": location_raw["watchLastLocate"]["lng"],
                                 "rad": location_raw["watchLastLocate"]["rad"],
@@ -201,21 +191,11 @@ class PyXploraApi(PyXplora):
                                 "city": location_raw["watchLastLocate"]["city"],
                                 "province": location_raw["watchLastLocate"]["province"],
                                 "country": location_raw["watchLastLocate"]["country"],
-                                "locateType": location_raw["watchLastLocate"][
-                                    "locateType"
-                                ],
-                                "isInSafeZone": location_raw["watchLastLocate"][
-                                    "isInSafeZone"
-                                ],
-                                "safeZoneLabel": location_raw["watchLastLocate"][
-                                    "safeZoneLabel"
-                                ],
-                                "watch_battery": location_raw["watchLastLocate"][
-                                    "battery"
-                                ],
-                                "watch_charging": location_raw["watchLastLocate"][
-                                    "isCharging"
-                                ],
+                                "locateType": location_raw["watchLastLocate"]["locateType"],
+                                "isInSafeZone": location_raw["watchLastLocate"]["isInSafeZone"],
+                                "safeZoneLabel": location_raw["watchLastLocate"]["safeZoneLabel"],
+                                "watch_battery": location_raw["watchLastLocate"]["battery"],
+                                "watch_charging": location_raw["watchLastLocate"]["isCharging"],
                                 "watch_last_location": location_raw["watchLastLocate"],
                             }
                         )
@@ -266,15 +246,11 @@ class PyXploraApi(PyXplora):
             raise Exception("Xplora API call finally failed with response: ")
 
     async def __setReadChatMsg_a(self, msgId, id):
-        return (
-            await self._gqlHandler.setReadChatMsg(self.getWatchUserID(), msgId, id)
-        )["setReadChatMsg"]
+        return (await self._gqlHandler.setReadChatMsg(self.getWatchUserID(), msgId, id))["setReadChatMsg"]
 
     async def getWatchUnReadChatMsgCount(self, watchID) -> int:
         # bug?
-        return (await self._gqlHandler.unReadChatMsgCount_a(watchID))[
-            "unReadChatMsgCount"
-        ]
+        return (await self._gqlHandler.unReadChatMsgCount_a(watchID))["unReadChatMsgCount"]
 
     async def getWatchChats(self, watchID) -> list:
         # bug?
@@ -323,9 +299,7 @@ class PyXploraApi(PyXplora):
 
     ##### Watch Location Info #####
     async def getWatchLastLocation(self, watchID, withAsk: bool = False) -> dict:
-        return (await self.loadWatchLocation(watchID=watchID, withAsk=withAsk))[0][
-            "watch_last_location"
-        ]
+        return (await self.loadWatchLocation(watchID=watchID, withAsk=withAsk))[0]["watch_last_location"]
 
     async def getWatchLocate(self, watchID) -> dict:
         return (await self.loadWatchLocation(watchID=watchID))[0]
@@ -457,9 +431,7 @@ class PyXploraApi(PyXplora):
             try:
                 await self.askWatchLocate(watchID)
                 await sleep(self.retryDelay)
-                disable_raw = await self._gqlHandler.setEnableSlientTime_a(
-                    silentId, NormalStatus.DISABLE.value
-                )
+                disable_raw = await self._gqlHandler.setEnableSlientTime_a(silentId, NormalStatus.DISABLE.value)
                 if "setEnableSilentTime" in disable_raw:
                     _raw = disable_raw["setEnableSilentTime"]
             except Exception as error:
@@ -519,9 +491,7 @@ class PyXploraApi(PyXplora):
             try:
                 await self.askWatchLocate(watchID)
                 await sleep(self.retryDelay)
-                disable_raw = await self._gqlHandler.setEnableAlarmTime_a(
-                    alarmId, NormalStatus.DISABLE.value
-                )
+                disable_raw = await self._gqlHandler.setEnableAlarmTime_a(alarmId, NormalStatus.DISABLE.value)
                 if "modifyAlarm" in disable_raw:
                     _raw = disable_raw["modifyAlarm"]
             except Exception as error:
